<?php
/**
 * Inserts JS at the end of <head> in the admin area,
 * enabling ACE on specified panels: css, page, form.
 */
function ace_styles_pages_forms_editor_add_js($event, $step)
{
    // Only run on these events
    $allowed_events = array('css', 'page', 'form');
    $current_event = gps('event');

    // Bail if not in the list
    if (!in_array($current_event, $allowed_events)) {
        return;
    }

    // Output the ACE script + custom init script
    // (Use a local copy or different CDN version if you prefer.)
    echo <<<EOD
<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.4.14/ace.js" charset="utf-8"></script>
<script>
document.addEventListener('DOMContentLoaded', function() {

    /**
     * Helper function: set up ACE on a textarea by ID, with a given ACE mode.
     *  - textareaId: the ID of the <textarea>
     *  - aceMode   : e.g. "ace/mode/css" or "ace/mode/php"
     */
    function setupAce(textareaId, aceMode) {
        var ta = document.getElementById(textareaId);
        if (!ta) {
            return; // No matching textarea found, skip
        }

        // Hide the original <textarea>
        ta.style.display = 'none';

        // Create a <div> for ACE
        var aceDiv = document.createElement('div');
        aceDiv.id = textareaId + '-ace-editor';
        aceDiv.style.width = '100%';
        aceDiv.style.height = '80vh'; // e.g. 80% of the viewport height

        // Insert ACE div right after the textarea
        ta.parentNode.insertBefore(aceDiv, ta.nextSibling);

        // Initialize ACE in that <div>
        var editor = ace.edit(aceDiv.id);
        editor.setTheme('ace/theme/chrome');  // or ace/theme/github, etc.
        editor.session.setMode(aceMode);

        // Load existing code from the textarea
        editor.setValue(ta.value, -1);

        // Don't show print lines
        editor.setShowPrintMargin(false);

        // Wrap code when longer than window
        editor.session.setOption('wrap', 'free');
        


        // Sync ACE → <textarea> so TXP can save updates
        editor.session.on('change', function() {
            ta.value = editor.getValue();
        });
    }

    // Decide which textareas to transform based on current event
    var evt = '{$current_event}';
    switch (evt) {
      case 'css':
        // Styles panel: <textarea id="css">
        setupAce('css', 'ace/mode/css');
        break;

      case 'page':
        // Pages panel: <textarea id="html">
        // Typically HTML/PHP, so we use "ace/mode/php"
        setupAce('html', 'ace/mode/php');
        break;

      case 'form':
        setupAce('form', 'ace/mode/php');
        break;
    }

});
</script>
EOD;
}

// Register callback to insert our script at admin-side head_end
if (@txpinterface == 'admin') {
    register_callback('ace_styles_pages_forms_editor_add_js', 'admin_side', 'head_end');
}
